/* @override http://localhost:8000/static/css/coop_bar.css */

/* */
#coop-bar {
	position: fixed;
	top: 10px;
	width: 160px;
	font-weight: lighter;
	-webkit-border-radius: 4px;
-moz-border-radius: 4px;
border-radius: 4px;
-webkit-box-shadow: #666 0px 2px 3px;
-moz-box-shadow: #666 0px 2px 3px;
box-shadow: #555 0px 2px 5px;
background: #FFFFFF;
background: -webkit-gradient(linear, 0 0, 0 bottom, from(#FFFFFF), to(#ABABAB));
background: -webkit-linear-gradient(#FFFFFF, #ABABAB);
background: -moz-linear-gradient(#FFFFFF, #ABABAB);
background: -ms-linear-gradient(#FFFFFF, #ABABAB);
background: -o-linear-gradient(#FFFFFF, #ABABAB);
background: linear-gradient(#FFFFFF, #ABABAB);
	padding: 20px 15px;
	right: 10px;
	text-align: left;
	z-index: 99999;
	font: 12px Tahoma, Arial,"Trebuchet MS", Trebuchet;
		cursor: move;

}


#coop-bar a {
    text-decoration: none;
	font-weight: bold;
	display: block;
	position: relative;
	padding-top: 3px;
	padding-bottom: 3px;
	color: #565656;
	border: 1px solid rgba(255,255,255,0);
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;

}

#coop-bar-status{
	margin-top: 10px;
	font-weight: bold;
}


#coop-bar a:hover {
	border: 1px solid #fff;
	background-color: rgba(255,255,255,0.5);
	color: #3b416d;
	box-shadow: #777 0 0 7px;
}

#coop-bar .separator {
	margin: 4px 0 4px 0;
	width: 100%;
	border: 1px solid #9b9c9c;
	border-bottom-style: solid;
	border-bottom-color: #e6e6e6;
}

 .icon { padding-left: 23px; background-repeat: no-repeat;
	background-position: 2px 2px;
}